pub fn extract_features(
el: &ElementRef<'_>,
stopwords: &HashSet<String>,
) -> NodeFeaturesExpand description
Compute the full feature set for a candidate node.
pub fn extract_features(
el: &ElementRef<'_>,
stopwords: &HashSet<String>,
) -> NodeFeaturesCompute the full feature set for a candidate node.