pub struct NodeClassifier { /* private fields */ }Expand description
A small MLP that maps NodeFeatures to a content-probability.
Implementations
Sourceimpl NodeClassifier
impl NodeClassifier
Sourcepub fn new(device: &Device, lr: f64) -> Result<Self>
pub fn new(device: &Device, lr: f64) -> Result<Self>
Create a new, randomly-initialized classifier.
Sourcepub fn score_batch(&self, features: &[NodeFeatures]) -> Result<Vec<f32>>
pub fn score_batch(&self, features: &[NodeFeatures]) -> Result<Vec<f32>>
Content probability in [0, 1] for each candidate.
Sourcepub fn select_best(&self, features: &[NodeFeatures]) -> Result<Option<usize>>
pub fn select_best(&self, features: &[NodeFeatures]) -> Result<Option<usize>>
Index of the candidate most likely to be the content root.
Sourcepub fn train_batch(
&mut self,
features: &[NodeFeatures],
labels: &[f32],
) -> Result<f32>
pub fn train_batch( &mut self, features: &[NodeFeatures], labels: &[f32], ) -> Result<f32>
One supervised gradient step over a batch of (features, label) pairs,
where label is 1.0 for the content node and 0.0 otherwise. Returns the
binary cross-entropy loss.
Sourcepub fn num_parameters(&self) -> usize
pub fn num_parameters(&self) -> usize
Number of trainable parameters (for logging / metadata).
Sourcepub fn save(&self, path: &Path) -> Result<()>
pub fn save(&self, path: &Path) -> Result<()>
Serialize the classifier weights to a .safetensors file.
Sourcepub fn load(path: &Path, device: &Device, lr: f64) -> Result<Self>
pub fn load(path: &Path, device: &Device, lr: f64) -> Result<Self>
Load a classifier previously written with Self::save.
The architecture is fixed (so new recreates the same variables) and the
stored tensors are copied into them; lr only affects subsequent
training and is irrelevant for inference.